@@ -30,6 +30,14 @@ int main()
    cout << "NTL_THREADS\n";
 #endif
 
+#ifdef NTL_DISABLE_TLS_HACK
+   cout << "NTL_DISABLE_TLS_HACK\n";
+#endif
+
+#ifdef NTL_ENABLE_TLS_HACK
+   cout << "NTL_ENABLE_TLS_HACK\n";
+#endif
+
 #ifdef NTL_EXCEPTIONS
    cout << "NTL_EXCEPTIONS\n";
 #endif
@@ -48,10 +56,6 @@ int main()
    cout << "NTL_GF2X_LIB\n";
 #endif
 
-#ifdef NTL_PCLMUL
-   cout << "NTL_PCLMUL\n";
-#endif
-
 #ifdef NTL_LONG_LONG_TYPE
    cout << "NTL_LONG_LONG_TYPE: ";
    cout << make_string(NTL_LONG_LONG_TYPE) << "\n";
@@ -178,6 +182,11 @@ cout << "Performance Options:\n";
    cout << "NTL_GF2X_NOINLINE\n";
 #endif
 
+#ifdef NTL_PCLMUL
+   cout << "NTL_PCLMUL\n";
+#endif
+
+
    cout << "\n\n";
 
    return 0;
