@@ -127,6 +127,20 @@ int main()
    cerr << "NTL_HAVE_LL_TYPE\n";
 #endif
 
+#ifdef NTL_HAVE_BUILTIN_CLZL
+   cerr << "NTL_HAVE_BUILTIN_CLZL\n";
+#endif
+
+#ifdef NTL_HAVE_AVX
+   cerr << "NTL_HAVE_AVX\n";
+#endif
+
+#ifdef NTL_HAVE_FMA
+   cerr << "NTL_HAVE_FMA\n";
+#endif
+
+
+
 #ifdef NTL_LONGDOUBLE_SP_MULMOD
    cerr << "NTL_LONGDOUBLE_SP_MULMOD\n";
 #endif
@@ -158,6 +172,14 @@ int main()
    cerr << "NTL_THREADS\n";
 #endif
 
+#ifdef NTL_DISABLE_TLS_HACK
+   cerr << "NTL_DISABLE_TLS_HACK\n";
+#endif
+
+#ifdef NTL_ENABLE_TLS_HACK
+   cerr << "NTL_ENABLE_TLS_HACK\n";
+#endif
+
 
 #ifdef NTL_EXCEPTIONS
    cerr << "NTL_EXCEPTIONS\n";
@@ -169,21 +191,21 @@ int main()
 
 
 #ifdef NTL_LEGACY_SP_MULMOD
-   cout << "NTL_LEGACY_SP_MULMOD\n";
+   cerr << "NTL_LEGACY_SP_MULMOD\n";
 #endif
 
 
 #ifdef NTL_DISABLE_LONGDOUBLE
-   cout << "NTL_DISABLE_LONGDOUBLE\n";
+   cerr << "NTL_DISABLE_LONGDOUBLE\n";
 #endif
 
 
 #ifdef NTL_DISABLE_LONGLONG
-   cout << "NTL_DISABLE_LONGLONG\n";
+   cerr << "NTL_DISABLE_LONGLONG\n";
 #endif
 
 #ifdef NTL_MAXIMIZE_SP_NBITS
-   cout << "NTL_MAXIMIZE_SP_NBITS\n";
+   cerr << "NTL_MAXIMIZE_SP_NBITS\n";
 #endif
 
 
@@ -199,10 +221,6 @@ int main()
 #endif
 
 
-#ifdef NTL_PCLMUL
-   cerr << "NTL_PCLMUL\n";
-#endif
-
 
 #ifdef NTL_LONG_LONG_TYPE
    cerr << "NTL_LONG_LONG_TYPE: ";
@@ -276,17 +294,14 @@ cerr << "Performance Options:\n";
 
 
 #ifdef NTL_FFT_BIGTAB
-   cout << "NTL_FFT_BIGTAB\n";
+   cerr << "NTL_FFT_BIGTAB\n";
 #endif
 
 #ifdef NTL_FFT_LAZYMUL
-   cout << "NTL_FFT_LAZYMUL\n";
+   cerr << "NTL_FFT_LAZYMUL\n";
 #endif
 
 
-
-
-
 #ifdef NTL_TBL_REM
    cerr << "NTL_TBL_REM\n";
 #endif
@@ -312,11 +327,15 @@ cerr << "Performance Options:\n";
    cerr << "NTL_GF2X_ALTCODE1\n";
 #endif
 
-
 #ifdef NTL_GF2X_NOINLINE
    cerr << "NTL_GF2X_NOINLINE\n";
 #endif
 
+#ifdef NTL_PCLMUL
+   cerr << "NTL_PCLMUL\n";
+#endif
+
+
    cerr << "\n\n";
 
    cerr << "running tests";
@@ -442,11 +461,11 @@ cerr << "Performance Options:\n";
    mul(j3, j1, j2);
 
    t = GetTime();
-   for (i = 0; i < 200; i++) mul(j3, j1, j2);
+   for (i = 0; i < 500; i++) mul(j3, j1, j2);
    t = GetTime()-t;
 
    cerr << "time to multiply degree 1023 polynomials\n   modulo a 1024-bit number: ";
-   cerr << (t/200) << "s";
+   cerr << (t/500) << "s";
    cerr << "\n";
 
    GF2X_time();
